/* set-properties.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from set-properties.vala, do not modify */

/*
 * Copyright (C) 2011, 2015 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *          Philip Withnall <philip.withnall@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <eds-test.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <gee.h>
#include <folks-test.h>


#define TYPE_SET_PROPERTIES_TESTS (set_properties_tests_get_type ())
#define SET_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_PROPERTIES_TESTS, SetPropertiesTests))
#define SET_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_PROPERTIES_TESTS, SetPropertiesTestsClass))
#define IS_SET_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_PROPERTIES_TESTS))
#define IS_SET_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_PROPERTIES_TESTS))
#define SET_PROPERTIES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_PROPERTIES_TESTS, SetPropertiesTestsClass))

typedef struct _SetPropertiesTests SetPropertiesTests;
typedef struct _SetPropertiesTestsClass SetPropertiesTestsClass;
typedef struct _SetPropertiesTestsPrivate SetPropertiesTestsPrivate;

#define SET_PROPERTIES_TESTS_TYPE_TEST_DETAILS (set_properties_tests_test_details_get_type ())
typedef struct _SetPropertiesTestsTestDetails SetPropertiesTestsTestDetails;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
typedef struct _Block2Data Block2Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SetPropertiesTests {
	EdsTestTestCase parent_instance;
	SetPropertiesTestsPrivate * priv;
};

struct _SetPropertiesTestsClass {
	EdsTestTestCaseClass parent_class;
};

typedef void (*SetPropertiesTestsPreCheck) (FolksIndividual* i, void* user_data);
typedef void (*SetPropertiesTestsSetProperty) (FolksPersona* p, void* user_data);
typedef void (*SetPropertiesTestsPostCheck) (FolksIndividual* i, void* user_data);
struct _SetPropertiesTestsTestDetails {
	gchar* prop_name;
	SetPropertiesTestsPreCheck pre_check;
	gpointer pre_check_target;
	SetPropertiesTestsSetProperty set_property;
	gpointer set_property_target;
	SetPropertiesTestsPostCheck post_check;
	gpointer post_check_target;
};

struct _Block1Data {
	int _ref_count_;
	SetPropertiesTests* self;
	SetPropertiesTestsTestDetails details;
};

struct _Block2Data {
	int _ref_count_;
	SetPropertiesTests* self;
	GMainLoop* main_loop;
	SetPropertiesTestsPostCheck post_check;
	gpointer post_check_target;
};


static gpointer set_properties_tests_parent_class = NULL;

GType set_properties_tests_get_type (void) G_GNUC_CONST;
enum  {
	SET_PROPERTIES_TESTS_DUMMY_PROPERTY
};
SetPropertiesTests* set_properties_tests_new (void);
SetPropertiesTests* set_properties_tests_construct (GType object_type);
static GType set_properties_tests_test_details_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SetPropertiesTestsTestDetails* set_properties_tests_test_details_dup (const SetPropertiesTestsTestDetails* self);
static void set_properties_tests_test_details_free (SetPropertiesTestsTestDetails* self);
static void set_properties_tests_test_details_copy (const SetPropertiesTestsTestDetails* self, SetPropertiesTestsTestDetails* dest);
static void set_properties_tests_test_details_destroy (SetPropertiesTestsTestDetails* self);
static void __lambda4_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda4__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda5_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda5__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda6_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda6__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda7_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda7__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda8_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda8__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda9_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda9__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda10_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda10__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda11_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda11__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda12_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda12__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda13_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda13__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda14_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda14__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda15_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda15__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda16_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda16__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda17_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda17__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda18_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda18__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda19_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda19__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda20_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda20__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda21_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda21__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda22_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda22__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda23_ (SetPropertiesTests* self, FolksPersona* p);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void ___lambda23__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda24_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda24__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda25_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda25__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda26_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda26__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda27_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda27__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda28_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda28__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda29_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda29__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda30_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda30__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda31_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda31__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda32_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda32__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda33_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda33__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static void __lambda34_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda34__set_properties_tests_pre_check (FolksIndividual* i, gpointer self);
static void __lambda35_ (SetPropertiesTests* self, FolksPersona* p);
static void ___lambda35__set_properties_tests_set_property (FolksPersona* p, gpointer self);
static void __lambda36_ (SetPropertiesTests* self, FolksIndividual* i);
static void ___lambda36__set_properties_tests_post_check (FolksIndividual* i, gpointer self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void ____lambda37_ (Block1Data* _data1_);
static void _set_properties_tests_test_set_property (SetPropertiesTests* self, const gchar* prop_name, SetPropertiesTestsPreCheck pre_check, void* pre_check_target, SetPropertiesTestsSetProperty set_property, void* set_property_target, SetPropertiesTestsPostCheck post_check, void* post_check_target);
static void _____lambda37__folks_test_case_test_method (gpointer self);
static void _vala_SetPropertiesTestsTestDetails_array_free (SetPropertiesTestsTestDetails* array, gint array_length);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static GValue* _g_value_dup (GValue* self);
static void _vala_GValue_free (GValue* self);
static void __lambda38_ (Block2Data* _data2_, GObject* o, GParamSpec* pspec);
static void ___lambda38__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void __lambda4_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	GDateTime* _tmp1_ = NULL;
	GDateTime* _tmp2_ = NULL;
#line 46 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 48 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 48 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp0_);
#line 48 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 48 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp2_ == NULL, "i.birthday == null");
#line 207 "set-properties.c"
}


static void ___lambda4__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda4_ ((SetPropertiesTests*) self, i);
#line 214 "set-properties.c"
}


static void __lambda5_ (SetPropertiesTests* self, FolksPersona* p) {
	GDateTime* dobj = NULL;
	GDateTime* _tmp0_ = NULL;
	GDateTime* _tmp1_ = NULL;
	GDateTime* _tmp2_ = NULL;
	GDateTime* _tmp3_ = NULL;
	FolksPersona* _tmp4_ = NULL;
#line 50 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 52 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = g_date_time_new_local (1980, 1, 1, 0, 0, 0.0);
#line 52 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = _tmp0_;
#line 52 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = g_date_time_to_utc (_tmp1_);
#line 52 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = _tmp2_;
#line 52 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_date_time_unref0 (_tmp1_);
#line 52 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	dobj = _tmp3_;
#line 53 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = p;
#line 53 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_birthday_details_set_birthday (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, FOLKS_TYPE_BIRTHDAY_DETAILS, FolksBirthdayDetails), dobj);
#line 50 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_date_time_unref0 (dobj);
#line 245 "set-properties.c"
}


static void ___lambda5__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda5_ ((SetPropertiesTests*) self, p);
#line 252 "set-properties.c"
}


static void __lambda6_ (SetPropertiesTests* self, FolksIndividual* i) {
	GDateTime* dobj = NULL;
	GDateTime* _tmp0_ = NULL;
	GDateTime* _tmp1_ = NULL;
	GDateTime* _tmp2_ = NULL;
	GDateTime* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	FolksIndividual* _tmp5_ = NULL;
	GDateTime* _tmp6_ = NULL;
	GDateTime* _tmp7_ = NULL;
#line 55 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 57 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = g_date_time_new_local (1980, 1, 1, 0, 0, 0.0);
#line 57 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = _tmp0_;
#line 57 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = g_date_time_to_utc (_tmp1_);
#line 57 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = _tmp2_;
#line 57 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_date_time_unref0 (_tmp1_);
#line 57 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	dobj = _tmp3_;
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_ = i;
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp6_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp5_);
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_ = _tmp6_;
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	if (_tmp7_ != NULL) {
#line 288 "set-properties.c"
		FolksIndividual* _tmp8_ = NULL;
		GDateTime* _tmp9_ = NULL;
		GDateTime* _tmp10_ = NULL;
		GDateTime* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp8_ = i;
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp9_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp8_);
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp10_ = _tmp9_;
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp11_ = dobj;
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp12_ = g_date_time_equal (_tmp10_, _tmp11_);
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp4_ = _tmp12_;
#line 306 "set-properties.c"
	} else {
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp4_ = FALSE;
#line 310 "set-properties.c"
	}
#line 58 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp4_, "i.birthday != null && i.birthday.equal (dobj)");
#line 55 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_date_time_unref0 (dobj);
#line 316 "set-properties.c"
}


static void ___lambda6__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda6_ ((SetPropertiesTests*) self, i);
#line 323 "set-properties.c"
}


static void __lambda7_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 64 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 66 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 66 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp0_);
#line 66 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 66 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (g_strcmp0 (_tmp2_, "bernie h. innocenti") == 0, "i.full_name == \"bernie h. innocenti\"");
#line 341 "set-properties.c"
}


static void ___lambda7__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda7_ ((SetPropertiesTests*) self, i);
#line 348 "set-properties.c"
}


static void __lambda8_ (SetPropertiesTests* self, FolksPersona* p) {
	FolksPersona* _tmp0_ = NULL;
#line 68 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 70 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = p;
#line 70 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_name_details_set_full_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails), "bernie");
#line 360 "set-properties.c"
}


static void ___lambda8__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda8_ ((SetPropertiesTests*) self, p);
#line 367 "set-properties.c"
}


static void __lambda9_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 72 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 74 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 74 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp0_);
#line 74 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 74 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (g_strcmp0 (_tmp2_, "bernie") == 0, "i.full_name == \"bernie\"");
#line 385 "set-properties.c"
}


static void ___lambda9__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda9_ ((SetPropertiesTests*) self, i);
#line 392 "set-properties.c"
}


static void __lambda10_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	FolksGender _tmp1_ = 0;
	FolksGender _tmp2_ = 0;
#line 80 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_gender_details_get_gender ((FolksGenderDetails*) _tmp0_);
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 82 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp2_ == FOLKS_GENDER_UNSPECIFIED, "i.gender == Gender.UNSPECIFIED");
#line 410 "set-properties.c"
}


static void ___lambda10__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda10_ ((SetPropertiesTests*) self, i);
#line 417 "set-properties.c"
}


static void __lambda11_ (SetPropertiesTests* self, FolksPersona* p) {
	FolksPersona* _tmp0_ = NULL;
#line 84 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 86 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = p;
#line 86 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_gender_details_set_gender (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_GENDER_DETAILS, FolksGenderDetails), FOLKS_GENDER_MALE);
#line 429 "set-properties.c"
}


static void ___lambda11__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda11_ ((SetPropertiesTests*) self, p);
#line 436 "set-properties.c"
}


static void __lambda12_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	FolksGender _tmp1_ = 0;
	FolksGender _tmp2_ = 0;
#line 88 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 90 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 90 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_gender_details_get_gender ((FolksGenderDetails*) _tmp0_);
#line 90 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 90 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp2_ == FOLKS_GENDER_MALE, "i.gender == Gender.MALE");
#line 454 "set-properties.c"
}


static void ___lambda12__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda12_ ((SetPropertiesTests*) self, i);
#line 461 "set-properties.c"
}


static void __lambda13_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 96 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 98 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 98 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp0_);
#line 98 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 98 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (!_tmp2_, "!i.is_favourite");
#line 479 "set-properties.c"
}


static void ___lambda13__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda13_ ((SetPropertiesTests*) self, i);
#line 486 "set-properties.c"
}


static void __lambda14_ (SetPropertiesTests* self, FolksPersona* p) {
	FolksPersona* _tmp0_ = NULL;
#line 100 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 102 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = p;
#line 102 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_favourite_details_set_is_favourite (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_FAVOURITE_DETAILS, FolksFavouriteDetails), TRUE);
#line 498 "set-properties.c"
}


static void ___lambda14__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda14_ ((SetPropertiesTests*) self, p);
#line 505 "set-properties.c"
}


static void __lambda15_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 104 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_favourite_details_get_is_favourite ((FolksFavouriteDetails*) _tmp0_);
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 106 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp2_, "i.is_favourite");
#line 523 "set-properties.c"
}


static void ___lambda15__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda15_ ((SetPropertiesTests*) self, i);
#line 530 "set-properties.c"
}


static void __lambda16_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 112 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 114 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 114 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_name_details_get_nickname ((FolksNameDetails*) _tmp0_);
#line 114 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 114 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (g_strcmp0 (_tmp2_, "") == 0, "i.nickname == \"\"");
#line 548 "set-properties.c"
}


static void ___lambda16__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda16_ ((SetPropertiesTests*) self, i);
#line 555 "set-properties.c"
}


static void __lambda17_ (SetPropertiesTests* self, FolksPersona* p) {
	FolksPersona* _tmp0_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 118 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = p;
#line 118 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_name_details_set_nickname (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails), "bernster");
#line 567 "set-properties.c"
}


static void ___lambda17__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda17_ ((SetPropertiesTests*) self, p);
#line 574 "set-properties.c"
}


static void __lambda18_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 120 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 122 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 122 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_name_details_get_nickname ((FolksNameDetails*) _tmp0_);
#line 122 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 122 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (g_strcmp0 (_tmp2_, "bernster") == 0, "i.nickname == \"bernster\"");
#line 592 "set-properties.c"
}


static void ___lambda18__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda18_ ((SetPropertiesTests*) self, i);
#line 599 "set-properties.c"
}


static void __lambda19_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 128 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 130 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 130 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_note_details_get_notes ((FolksNoteDetails*) _tmp0_);
#line 130 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 130 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
#line 130 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = _tmp3_;
#line 130 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp4_ == 0, "i.notes.size == 0");
#line 623 "set-properties.c"
}


static void ___lambda19__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda19_ ((SetPropertiesTests*) self, i);
#line 630 "set-properties.c"
}


static void __lambda20_ (SetPropertiesTests* self, FolksPersona* p) {
	GeeHashSet* notes = NULL;
	GeeHashSet* _tmp0_ = NULL;
	FolksNoteFieldDetails* note = NULL;
	FolksNoteFieldDetails* _tmp1_ = NULL;
	FolksPersona* _tmp2_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 134 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = gee_hash_set_new (FOLKS_TYPE_NOTE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 134 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	notes = _tmp0_;
#line 135 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_note_field_details_new ("This is a note.", NULL, NULL);
#line 135 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	note = _tmp1_;
#line 136 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) notes, note);
#line 137 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = p;
#line 137 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_note_details_set_notes (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, FOLKS_TYPE_NOTE_DETAILS, FolksNoteDetails), (GeeSet*) notes);
#line 132 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (note);
#line 132 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (notes);
#line 660 "set-properties.c"
}


static void ___lambda20__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda20_ ((SetPropertiesTests*) self, p);
#line 667 "set-properties.c"
}


static void __lambda21_ (SetPropertiesTests* self, FolksIndividual* i) {
#line 139 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 674 "set-properties.c"
	{
		GeeIterator* _note_it = NULL;
		FolksIndividual* _tmp0_ = NULL;
		GeeSet* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp0_ = i;
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp1_ = folks_note_details_get_notes ((FolksNoteDetails*) _tmp0_);
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp2_ = _tmp1_;
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_note_it = _tmp3_;
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		while (TRUE) {
#line 693 "set-properties.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksNoteFieldDetails* note = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksNoteFieldDetails* _tmp8_ = NULL;
			FolksNoteFieldDetails* _tmp9_ = NULL;
			FolksNoteFieldDetails* _tmp10_ = NULL;
			gboolean _tmp11_ = FALSE;
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp4_ = _note_it;
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			if (!_tmp5_) {
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				break;
#line 711 "set-properties.c"
			}
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp6_ = _note_it;
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			note = (FolksNoteFieldDetails*) _tmp7_;
#line 143 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp8_ = note;
#line 143 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp9_ = folks_note_field_details_new ("This is a note.", NULL, NULL);
#line 143 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp10_ = _tmp9_;
#line 143 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp11_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp8_, (FolksAbstractFieldDetails*) _tmp10_);
#line 143 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_vala_assert (_tmp11_, "note.equal (                       new NoteFieldDetails (\"This is a note.\"))");
#line 143 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_g_object_unref0 (_tmp10_);
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_g_object_unref0 (note);
#line 733 "set-properties.c"
		}
#line 141 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_g_object_unref0 (_note_it);
#line 737 "set-properties.c"
	}
}


static void ___lambda21__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda21_ ((SetPropertiesTests*) self, i);
#line 745 "set-properties.c"
}


static void __lambda22_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 151 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 153 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 153 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp0_);
#line 153 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 153 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
#line 153 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = _tmp3_;
#line 153 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp4_ == 0, "i.phone_numbers.size == 0");
#line 769 "set-properties.c"
}


static void ___lambda22__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda22_ ((SetPropertiesTests*) self, i);
#line 776 "set-properties.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 157 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return result;
#line 785 "set-properties.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 157 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return result;
#line 794 "set-properties.c"
}


static void __lambda23_ (SetPropertiesTests* self, FolksPersona* p) {
	GeeHashSet* phones = NULL;
	GeeHashSet* _tmp0_ = NULL;
	FolksPhoneFieldDetails* phone_1 = NULL;
	FolksPhoneFieldDetails* _tmp1_ = NULL;
	FolksPersona* _tmp2_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 157 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = gee_hash_set_new (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 157 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	phones = _tmp0_;
#line 160 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_phone_field_details_new ("1234", NULL);
#line 160 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	phone_1 = _tmp1_;
#line 161 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) phone_1, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 163 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) phones, phone_1);
#line 164 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = p;
#line 164 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_phone_details_set_phone_numbers (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, FOLKS_TYPE_PHONE_DETAILS, FolksPhoneDetails), (GeeSet*) phones);
#line 155 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (phone_1);
#line 155 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (phones);
#line 826 "set-properties.c"
}


static void ___lambda23__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda23_ ((SetPropertiesTests*) self, p);
#line 833 "set-properties.c"
}


static void __lambda24_ (SetPropertiesTests* self, FolksIndividual* i) {
	gboolean found = FALSE;
	gboolean _tmp19_ = FALSE;
#line 166 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 168 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	found = FALSE;
#line 844 "set-properties.c"
	{
		GeeIterator* _phone_fd_it = NULL;
		FolksIndividual* _tmp0_ = NULL;
		GeeSet* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp0_ = i;
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp1_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp0_);
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp2_ = _tmp1_;
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_phone_fd_it = _tmp3_;
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		while (TRUE) {
#line 863 "set-properties.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksPhoneFieldDetails* phone_fd = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksPhoneFieldDetails* _tmp8_ = NULL;
			gconstpointer _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp4_ = _phone_fd_it;
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			if (!_tmp5_) {
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				break;
#line 880 "set-properties.c"
			}
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp6_ = _phone_fd_it;
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			phone_fd = (FolksPhoneFieldDetails*) _tmp7_;
#line 188 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp8_ = phone_fd;
#line 188 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp9_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp8_);
#line 188 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp10_ = _tmp9_;
#line 188 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			if (g_strcmp0 ((const gchar*) _tmp10_, "1234") == 0) {
#line 896 "set-properties.c"
				GeeCollection* vals = NULL;
				FolksPhoneFieldDetails* _tmp11_ = NULL;
				GeeCollection* _tmp12_ = NULL;
				GeeCollection* _tmp13_ = NULL;
				GeeCollection* _tmp14_ = NULL;
				gint _tmp15_ = 0;
				gint _tmp16_ = 0;
				GeeCollection* _tmp17_ = NULL;
				gboolean _tmp18_ = FALSE;
#line 190 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				found = TRUE;
#line 191 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp11_ = phone_fd;
#line 191 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp12_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp11_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE);
#line 191 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				vals = _tmp12_;
#line 192 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp13_ = vals;
#line 192 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_vala_assert (_tmp13_ != NULL, "vals != null");
#line 193 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp14_ = vals;
#line 193 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp15_ = gee_collection_get_size (_tmp14_);
#line 193 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp16_ = _tmp15_;
#line 193 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_vala_assert (_tmp16_ == 1, "vals.size == 1");
#line 194 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp17_ = vals;
#line 194 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp18_ = gee_collection_contains (_tmp17_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 194 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_vala_assert (_tmp18_, "vals.contains (AbstractFieldDetails.PARAM_TYPE_HOME)");
#line 188 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_g_object_unref0 (vals);
#line 934 "set-properties.c"
			}
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_g_object_unref0 (phone_fd);
#line 938 "set-properties.c"
		}
#line 170 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_g_object_unref0 (_phone_fd_it);
#line 942 "set-properties.c"
	}
#line 198 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp19_ = found;
#line 198 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp19_, "found");
#line 948 "set-properties.c"
}


static void ___lambda24__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda24_ ((SetPropertiesTests*) self, i);
#line 955 "set-properties.c"
}


static void __lambda25_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 204 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 206 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 206 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _tmp0_);
#line 206 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 206 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
#line 206 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = _tmp3_;
#line 206 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp4_ == 0, "i.postal_addresses.size == 0");
#line 979 "set-properties.c"
}


static void ___lambda25__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda25_ ((SetPropertiesTests*) self, i);
#line 986 "set-properties.c"
}


static void __lambda26_ (SetPropertiesTests* self, FolksPersona* p) {
	GeeHashSet* pa_fds = NULL;
	GeeHashSet* _tmp0_ = NULL;
	FolksPostalAddress* pa_1 = NULL;
	FolksPostalAddress* _tmp1_ = NULL;
	FolksPostalAddressFieldDetails* pa_fd_1 = NULL;
	FolksPostalAddressFieldDetails* _tmp2_ = NULL;
	FolksPersona* _tmp3_ = NULL;
#line 208 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 210 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = gee_hash_set_new (FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 210 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	pa_fds = _tmp0_;
#line 211 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_postal_address_new ("123", "extension", "street", "locality", "region", "postal code", "country", "format", "123");
#line 211 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	pa_1 = _tmp1_;
#line 214 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = folks_postal_address_field_details_new (pa_1, NULL);
#line 214 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	pa_fd_1 = _tmp2_;
#line 215 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) pa_fd_1, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 217 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) pa_fds, pa_fd_1);
#line 218 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = p;
#line 218 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_postal_address_details_set_postal_addresses (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, FOLKS_TYPE_POSTAL_ADDRESS_DETAILS, FolksPostalAddressDetails), (GeeSet*) pa_fds);
#line 208 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (pa_fd_1);
#line 208 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (pa_1);
#line 208 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (pa_fds);
#line 1026 "set-properties.c"
}


static void ___lambda26__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda26_ ((SetPropertiesTests*) self, p);
#line 1033 "set-properties.c"
}


static void __lambda27_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksPostalAddress* pa = NULL;
	FolksPostalAddress* _tmp0_ = NULL;
	FolksPostalAddressFieldDetails* expected_pa_fd = NULL;
	FolksPostalAddress* _tmp1_ = NULL;
	FolksPostalAddressFieldDetails* _tmp2_ = NULL;
	FolksPostalAddressFieldDetails* _tmp3_ = NULL;
#line 220 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 222 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = folks_postal_address_new ("123", "extension", "street", "locality", "region", "postal code", "country", "", "123");
#line 222 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	pa = _tmp0_;
#line 225 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = pa;
#line 225 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = folks_postal_address_field_details_new (_tmp1_, NULL);
#line 225 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	expected_pa_fd = _tmp2_;
#line 226 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = expected_pa_fd;
#line 226 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp3_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_OTHER);
#line 1060 "set-properties.c"
	{
		GeeIterator* _pa_fd_it = NULL;
		FolksIndividual* _tmp4_ = NULL;
		GeeSet* _tmp5_ = NULL;
		GeeSet* _tmp6_ = NULL;
		GeeIterator* _tmp7_ = NULL;
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp4_ = i;
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp5_ = folks_postal_address_details_get_postal_addresses ((FolksPostalAddressDetails*) _tmp4_);
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp6_ = _tmp5_;
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_pa_fd_it = _tmp7_;
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		while (TRUE) {
#line 1079 "set-properties.c"
			GeeIterator* _tmp8_ = NULL;
			gboolean _tmp9_ = FALSE;
			FolksPostalAddressFieldDetails* pa_fd = NULL;
			GeeIterator* _tmp10_ = NULL;
			gpointer _tmp11_ = NULL;
			FolksPostalAddressFieldDetails* _tmp12_ = NULL;
			FolksPostalAddressFieldDetails* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			FolksPostalAddressFieldDetails* _tmp16_ = NULL;
			FolksPostalAddressFieldDetails* _tmp17_ = NULL;
			gboolean _tmp18_ = FALSE;
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp8_ = _pa_fd_it;
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			if (!_tmp9_) {
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				break;
#line 1100 "set-properties.c"
			}
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp10_ = _pa_fd_it;
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			pa_fd = (FolksPostalAddressFieldDetails*) _tmp11_;
#line 231 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp12_ = pa_fd;
#line 231 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp13_ = expected_pa_fd;
#line 231 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp14_ = folks_abstract_field_details_get_id ((FolksAbstractFieldDetails*) _tmp13_);
#line 231 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp15_ = _tmp14_;
#line 231 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			folks_abstract_field_details_set_id ((FolksAbstractFieldDetails*) _tmp12_, _tmp15_);
#line 232 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp16_ = pa_fd;
#line 232 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp17_ = expected_pa_fd;
#line 232 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp18_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp16_, (FolksAbstractFieldDetails*) _tmp17_);
#line 232 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_vala_assert (_tmp18_, "pa_fd.equal (expected_pa_fd)");
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_g_object_unref0 (pa_fd);
#line 1128 "set-properties.c"
		}
#line 229 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_g_object_unref0 (_pa_fd_it);
#line 1132 "set-properties.c"
	}
#line 220 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (expected_pa_fd);
#line 220 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (pa);
#line 1138 "set-properties.c"
}


static void ___lambda27__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda27_ ((SetPropertiesTests*) self, i);
#line 1145 "set-properties.c"
}


static void __lambda28_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 239 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 241 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 241 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_role_details_get_roles ((FolksRoleDetails*) _tmp0_);
#line 241 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 241 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
#line 241 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = _tmp3_;
#line 241 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp4_ == 0, "i.roles.size == 0");
#line 1169 "set-properties.c"
}


static void ___lambda28__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda28_ ((SetPropertiesTests*) self, i);
#line 1176 "set-properties.c"
}


static void __lambda29_ (SetPropertiesTests* self, FolksPersona* p) {
	GeeHashSet* role_fds = NULL;
	GeeHashSet* _tmp0_ = NULL;
	FolksRole* r1 = NULL;
	FolksRole* _tmp1_ = NULL;
	FolksRoleFieldDetails* role_fd1 = NULL;
	FolksRoleFieldDetails* _tmp2_ = NULL;
	FolksPersona* _tmp3_ = NULL;
#line 243 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 245 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = gee_hash_set_new (FOLKS_TYPE_ROLE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 245 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	role_fds = _tmp0_;
#line 248 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_role_new ("Dr.", "The Nut House Ltd", NULL);
#line 248 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	r1 = _tmp1_;
#line 249 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_role_set_role (r1, "The Manager");
#line 250 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = folks_role_field_details_new (r1, NULL);
#line 250 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	role_fd1 = _tmp2_;
#line 251 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) role_fds, role_fd1);
#line 252 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = p;
#line 252 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_role_details_set_roles (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, FOLKS_TYPE_ROLE_DETAILS, FolksRoleDetails), (GeeSet*) role_fds);
#line 243 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (role_fd1);
#line 243 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (r1);
#line 243 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (role_fds);
#line 1216 "set-properties.c"
}


static void ___lambda29__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda29_ ((SetPropertiesTests*) self, p);
#line 1223 "set-properties.c"
}


static void __lambda30_ (SetPropertiesTests* self, FolksIndividual* i) {
#line 254 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 1230 "set-properties.c"
	{
		GeeIterator* _role_fd_it = NULL;
		FolksIndividual* _tmp0_ = NULL;
		GeeSet* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp0_ = i;
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp1_ = folks_role_details_get_roles ((FolksRoleDetails*) _tmp0_);
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp2_ = _tmp1_;
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_role_fd_it = _tmp3_;
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		while (TRUE) {
#line 1249 "set-properties.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksRoleFieldDetails* role_fd = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksRole* r1 = NULL;
			FolksRole* _tmp8_ = NULL;
			FolksRole* _tmp9_ = NULL;
			FolksRoleFieldDetails* role_fd_expected = NULL;
			FolksRole* _tmp10_ = NULL;
			FolksRoleFieldDetails* _tmp11_ = NULL;
			FolksRoleFieldDetails* _tmp12_ = NULL;
			FolksRoleFieldDetails* _tmp13_ = NULL;
			gboolean _tmp14_ = FALSE;
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp4_ = _role_fd_it;
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			if (!_tmp5_) {
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				break;
#line 1272 "set-properties.c"
			}
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp6_ = _role_fd_it;
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			role_fd = (FolksRoleFieldDetails*) _tmp7_;
#line 258 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp8_ = folks_role_new ("Dr.", "The Nut House Ltd", NULL);
#line 258 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			r1 = _tmp8_;
#line 259 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp9_ = r1;
#line 259 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			folks_role_set_role (_tmp9_, "The Manager");
#line 260 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp10_ = r1;
#line 260 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp11_ = folks_role_field_details_new (_tmp10_, NULL);
#line 260 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			role_fd_expected = _tmp11_;
#line 261 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp12_ = role_fd;
#line 261 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp13_ = role_fd_expected;
#line 261 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp14_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp12_, (FolksAbstractFieldDetails*) _tmp13_);
#line 261 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_vala_assert (_tmp14_, "role_fd.equal (role_fd_expected)");
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_g_object_unref0 (role_fd_expected);
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_g_object_unref0 (r1);
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_g_object_unref0 (role_fd);
#line 1308 "set-properties.c"
		}
#line 256 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_g_object_unref0 (_role_fd_it);
#line 1312 "set-properties.c"
	}
}


static void ___lambda30__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda30_ ((SetPropertiesTests*) self, i);
#line 1320 "set-properties.c"
}


static void __lambda31_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	FolksStructuredName* _tmp1_ = NULL;
	FolksStructuredName* _tmp2_ = NULL;
#line 268 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 270 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 270 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_name_details_get_structured_name ((FolksNameDetails*) _tmp0_);
#line 270 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 270 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp2_ != NULL, "i.structured_name != null");
#line 1338 "set-properties.c"
}


static void ___lambda31__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda31_ ((SetPropertiesTests*) self, i);
#line 1345 "set-properties.c"
}


static void __lambda32_ (SetPropertiesTests* self, FolksPersona* p) {
	FolksPersona* _tmp0_ = NULL;
	FolksStructuredName* _tmp1_ = NULL;
	FolksStructuredName* _tmp2_ = NULL;
#line 272 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 274 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = p;
#line 274 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_structured_name_new_simple ("Neutron", "Jimmy");
#line 274 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 274 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_name_details_set_structured_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_NAME_DETAILS, FolksNameDetails), _tmp2_);
#line 274 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (_tmp2_);
#line 1365 "set-properties.c"
}


static void ___lambda32__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda32_ ((SetPropertiesTests*) self, p);
#line 1372 "set-properties.c"
}


static void __lambda33_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	FolksStructuredName* _tmp1_ = NULL;
	FolksStructuredName* _tmp2_ = NULL;
	FolksStructuredName* _tmp3_ = NULL;
	FolksStructuredName* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 277 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 279 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 279 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_name_details_get_structured_name ((FolksNameDetails*) _tmp0_);
#line 279 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 279 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = folks_structured_name_new_simple ("Neutron", "Jimmy");
#line 279 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = _tmp3_;
#line 279 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_ = folks_structured_name_equal (_tmp2_, _tmp4_);
#line 279 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp5_, "i.structured_name.equal (                   new StructuredName.simple (\"Neutron\", \"Jimmy\"))");
#line 279 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (_tmp4_);
#line 1401 "set-properties.c"
}


static void ___lambda33__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda33_ ((SetPropertiesTests*) self, i);
#line 1408 "set-properties.c"
}


static void __lambda34_ (SetPropertiesTests* self, FolksIndividual* i) {
	FolksIndividual* _tmp0_ = NULL;
	GeeSet* _tmp1_ = NULL;
	GeeSet* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 286 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 288 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = i;
#line 288 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp0_);
#line 288 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _tmp1_;
#line 288 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
#line 288 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = _tmp3_;
#line 288 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp4_ == 0, "i.urls.size == 0");
#line 1432 "set-properties.c"
}


static void ___lambda34__set_properties_tests_pre_check (FolksIndividual* i, gpointer self) {
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda34_ ((SetPropertiesTests*) self, i);
#line 1439 "set-properties.c"
}


static void __lambda35_ (SetPropertiesTests* self, FolksPersona* p) {
	GeeHashSet* urls = NULL;
	GeeHashSet* _tmp0_ = NULL;
	FolksUrlFieldDetails* p1 = NULL;
	FolksUrlFieldDetails* _tmp1_ = NULL;
	FolksUrlFieldDetails* p2 = NULL;
	FolksUrlFieldDetails* _tmp2_ = NULL;
	FolksUrlFieldDetails* p3 = NULL;
	FolksUrlFieldDetails* _tmp3_ = NULL;
	FolksUrlFieldDetails* p4 = NULL;
	FolksUrlFieldDetails* _tmp4_ = NULL;
	FolksPersona* _tmp5_ = NULL;
#line 290 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (p != NULL);
#line 292 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = gee_hash_set_new (FOLKS_TYPE_URL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 292 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	urls = _tmp0_;
#line 294 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = folks_url_field_details_new ("http://example.org", NULL);
#line 294 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	p1 = _tmp1_;
#line 295 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) urls, p1);
#line 296 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = folks_url_field_details_new ("http://extra.example.org", NULL);
#line 296 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	p2 = _tmp2_;
#line 297 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) urls, p2);
#line 298 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = folks_url_field_details_new ("http://home.example.org", NULL);
#line 298 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	p3 = _tmp3_;
#line 299 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) p3, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_HOME_PAGE);
#line 301 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) urls, p3);
#line 302 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = folks_url_field_details_new ("http://blog.example.org", NULL);
#line 302 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	p4 = _tmp4_;
#line 303 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) p4, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_URL_FIELD_DETAILS_PARAM_TYPE_BLOG);
#line 305 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) urls, p4);
#line 307 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_ = p;
#line 307 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_url_details_set_urls (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, FOLKS_TYPE_URL_DETAILS, FolksUrlDetails), (GeeSet*) urls);
#line 290 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (p4);
#line 290 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (p3);
#line 290 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (p2);
#line 290 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (p1);
#line 290 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (urls);
#line 1503 "set-properties.c"
}


static void ___lambda35__set_properties_tests_set_property (FolksPersona* p, gpointer self) {
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda35_ ((SetPropertiesTests*) self, p);
#line 1510 "set-properties.c"
}


static void __lambda36_ (SetPropertiesTests* self, FolksIndividual* i) {
	gboolean found_url_extra_1 = FALSE;
	gboolean found_url_extra_2 = FALSE;
	gboolean found_url_home = FALSE;
	gboolean found_url_blog = FALSE;
	gboolean _tmp20_ = FALSE;
	gboolean _tmp21_ = FALSE;
	gboolean _tmp22_ = FALSE;
	gboolean _tmp23_ = FALSE;
#line 309 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (i != NULL);
#line 311 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	found_url_extra_1 = FALSE;
#line 312 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	found_url_extra_2 = FALSE;
#line 313 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	found_url_home = FALSE;
#line 314 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	found_url_blog = FALSE;
#line 1533 "set-properties.c"
	{
		GeeIterator* _url_it = NULL;
		FolksIndividual* _tmp0_ = NULL;
		GeeSet* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp0_ = i;
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp1_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp0_);
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp2_ = _tmp1_;
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_url_it = _tmp3_;
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		while (TRUE) {
#line 1552 "set-properties.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksUrlFieldDetails* url = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksUrlFieldDetails* _tmp8_ = NULL;
			gconstpointer _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp4_ = _url_it;
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			if (!_tmp5_) {
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				break;
#line 1569 "set-properties.c"
			}
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp6_ = _url_it;
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			url = (FolksUrlFieldDetails*) _tmp7_;
#line 318 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp8_ = url;
#line 318 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp9_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp8_);
#line 318 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp10_ = _tmp9_;
#line 318 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			if (g_strcmp0 ((const gchar*) _tmp10_, "http://example.org") == 0) {
#line 319 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				found_url_extra_1 = TRUE;
#line 1587 "set-properties.c"
			} else {
				FolksUrlFieldDetails* _tmp11_ = NULL;
				gconstpointer _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
#line 320 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp11_ = url;
#line 320 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp12_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp11_);
#line 320 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp13_ = _tmp12_;
#line 320 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				if (g_strcmp0 ((const gchar*) _tmp13_, "http://extra.example.org") == 0) {
#line 321 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
					found_url_extra_2 = TRUE;
#line 1602 "set-properties.c"
				} else {
					FolksUrlFieldDetails* _tmp14_ = NULL;
					gconstpointer _tmp15_ = NULL;
					const gchar* _tmp16_ = NULL;
#line 322 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
					_tmp14_ = url;
#line 322 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
					_tmp15_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp14_);
#line 322 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
					_tmp16_ = _tmp15_;
#line 322 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
					if (g_strcmp0 ((const gchar*) _tmp16_, "http://home.example.org") == 0) {
#line 323 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
						found_url_home = TRUE;
#line 1617 "set-properties.c"
					} else {
						FolksUrlFieldDetails* _tmp17_ = NULL;
						gconstpointer _tmp18_ = NULL;
						const gchar* _tmp19_ = NULL;
#line 324 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
						_tmp17_ = url;
#line 324 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
						_tmp18_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp17_);
#line 324 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
						_tmp19_ = _tmp18_;
#line 324 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
						if (g_strcmp0 ((const gchar*) _tmp19_, "http://blog.example.org") == 0) {
#line 325 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
							found_url_blog = TRUE;
#line 1632 "set-properties.c"
						}
					}
				}
			}
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_g_object_unref0 (url);
#line 1639 "set-properties.c"
		}
#line 316 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_g_object_unref0 (_url_it);
#line 1643 "set-properties.c"
	}
#line 328 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp20_ = found_url_extra_1;
#line 328 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp20_, "found_url_extra_1");
#line 329 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp21_ = found_url_extra_2;
#line 329 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp21_, "found_url_extra_2");
#line 330 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp22_ = found_url_home;
#line 330 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp22_, "found_url_home");
#line 331 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp23_ = found_url_blog;
#line 331 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_vala_assert (_tmp23_, "found_url_blog");
#line 1661 "set-properties.c"
}


static void ___lambda36__set_properties_tests_post_check (FolksIndividual* i, gpointer self) {
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda36_ ((SetPropertiesTests*) self, i);
#line 1668 "set-properties.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return _data1_;
#line 1677 "set-properties.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 1686 "set-properties.c"
		SetPropertiesTests* self;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		self = _data1_->self;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		set_properties_tests_test_details_destroy (&_data1_->details);
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_g_object_unref0 (self);
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		g_slice_free (Block1Data, _data1_);
#line 1696 "set-properties.c"
	}
}


static void ____lambda37_ (Block1Data* _data1_) {
	SetPropertiesTests* self;
	SetPropertiesTestsTestDetails _tmp0_ = {0};
	const gchar* _tmp1_ = NULL;
	SetPropertiesTestsTestDetails _tmp2_ = {0};
	SetPropertiesTestsPreCheck _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	SetPropertiesTestsTestDetails _tmp4_ = {0};
	SetPropertiesTestsSetProperty _tmp5_ = NULL;
	void* _tmp5__target = NULL;
	SetPropertiesTestsTestDetails _tmp6_ = {0};
	SetPropertiesTestsPostCheck _tmp7_ = NULL;
	void* _tmp7__target = NULL;
#line 366 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	self = _data1_->self;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = _data1_->details;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = _tmp0_.prop_name;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _data1_->details;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = _tmp2_.pre_check;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3__target = _tmp2_.pre_check_target;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = _data1_->details;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_ = _tmp4_.set_property;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5__target = _tmp4_.set_property_target;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp6_ = _data1_->details;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_ = _tmp6_.post_check;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7__target = _tmp6_.post_check_target;
#line 368 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_set_properties_tests_test_set_property (self, _tmp1_, _tmp3_, _tmp3__target, _tmp5_, _tmp5__target, _tmp7_, _tmp7__target);
#line 1740 "set-properties.c"
}


static void _____lambda37__folks_test_case_test_method (gpointer self) {
#line 366 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	____lambda37_ (self);
#line 1747 "set-properties.c"
}


static void _vala_SetPropertiesTestsTestDetails_array_free (SetPropertiesTestsTestDetails* array, gint array_length) {
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	if (array != NULL) {
#line 1754 "set-properties.c"
		int i;
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			set_properties_tests_test_details_destroy (&array[i]);
#line 1760 "set-properties.c"
		}
	}
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_free (array);
#line 1765 "set-properties.c"
}


SetPropertiesTests* set_properties_tests_construct (GType object_type) {
	SetPropertiesTests * self = NULL;
	SetPropertiesTestsTestDetails birthday_details = {0};
	gchar* _tmp0_ = NULL;
	SetPropertiesTestsTestDetails _tmp1_ = {0};
	SetPropertiesTestsTestDetails full_name_details = {0};
	gchar* _tmp2_ = NULL;
	SetPropertiesTestsTestDetails _tmp3_ = {0};
	SetPropertiesTestsTestDetails gender_details = {0};
	gchar* _tmp4_ = NULL;
	SetPropertiesTestsTestDetails _tmp5_ = {0};
	SetPropertiesTestsTestDetails is_favourite_details = {0};
	gchar* _tmp6_ = NULL;
	SetPropertiesTestsTestDetails _tmp7_ = {0};
	SetPropertiesTestsTestDetails nickname_details = {0};
	gchar* _tmp8_ = NULL;
	SetPropertiesTestsTestDetails _tmp9_ = {0};
	SetPropertiesTestsTestDetails notes_details = {0};
	gchar* _tmp10_ = NULL;
	SetPropertiesTestsTestDetails _tmp11_ = {0};
	SetPropertiesTestsTestDetails phone_numbers_details = {0};
	gchar* _tmp12_ = NULL;
	SetPropertiesTestsTestDetails _tmp13_ = {0};
	SetPropertiesTestsTestDetails postal_addresses_details = {0};
	gchar* _tmp14_ = NULL;
	SetPropertiesTestsTestDetails _tmp15_ = {0};
	SetPropertiesTestsTestDetails roles_details = {0};
	gchar* _tmp16_ = NULL;
	SetPropertiesTestsTestDetails _tmp17_ = {0};
	SetPropertiesTestsTestDetails structured_name_details = {0};
	gchar* _tmp18_ = NULL;
	SetPropertiesTestsTestDetails _tmp19_ = {0};
	SetPropertiesTestsTestDetails urls_details = {0};
	gchar* _tmp20_ = NULL;
	SetPropertiesTestsTestDetails _tmp21_ = {0};
	SetPropertiesTestsTestDetails* properties = NULL;
	SetPropertiesTestsTestDetails _tmp22_ = {0};
	SetPropertiesTestsTestDetails _tmp23_ = {0};
	SetPropertiesTestsTestDetails _tmp24_ = {0};
	SetPropertiesTestsTestDetails _tmp25_ = {0};
	SetPropertiesTestsTestDetails _tmp26_ = {0};
	SetPropertiesTestsTestDetails _tmp27_ = {0};
	SetPropertiesTestsTestDetails _tmp28_ = {0};
	SetPropertiesTestsTestDetails _tmp29_ = {0};
	SetPropertiesTestsTestDetails _tmp30_ = {0};
	SetPropertiesTestsTestDetails _tmp31_ = {0};
	SetPropertiesTestsTestDetails _tmp32_ = {0};
	SetPropertiesTestsTestDetails _tmp33_ = {0};
	SetPropertiesTestsTestDetails _tmp34_ = {0};
	SetPropertiesTestsTestDetails _tmp35_ = {0};
	SetPropertiesTestsTestDetails _tmp36_ = {0};
	SetPropertiesTestsTestDetails _tmp37_ = {0};
	SetPropertiesTestsTestDetails _tmp38_ = {0};
	SetPropertiesTestsTestDetails _tmp39_ = {0};
	SetPropertiesTestsTestDetails _tmp40_ = {0};
	SetPropertiesTestsTestDetails _tmp41_ = {0};
	SetPropertiesTestsTestDetails _tmp42_ = {0};
	SetPropertiesTestsTestDetails _tmp43_ = {0};
	SetPropertiesTestsTestDetails* _tmp44_ = NULL;
	gint properties_length1 = 0;
	gint _properties_size_ = 0;
	SetPropertiesTestsTestDetails* _tmp45_ = NULL;
	gint _tmp45__length1 = 0;
#line 41 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	self = (SetPropertiesTests*) eds_test_test_case_construct (object_type, "SetProperties");
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = g_strdup ("birthday");
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp1_.prop_name);
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_.prop_name = _tmp0_;
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_.pre_check = ___lambda4__set_properties_tests_pre_check;
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_.pre_check_target = self;
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_.set_property = ___lambda5__set_properties_tests_set_property;
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_.set_property_target = self;
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_.post_check = ___lambda6__set_properties_tests_post_check;
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_.post_check_target = self;
#line 44 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	birthday_details = _tmp1_;
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = g_strdup ("full-name");
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp3_.prop_name);
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_.prop_name = _tmp2_;
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_.pre_check = ___lambda7__set_properties_tests_pre_check;
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_.pre_check_target = self;
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_.set_property = ___lambda8__set_properties_tests_set_property;
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_.set_property_target = self;
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_.post_check = ___lambda9__set_properties_tests_post_check;
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_.post_check_target = self;
#line 62 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	full_name_details = _tmp3_;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = g_strdup ("gender");
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp5_.prop_name);
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_.prop_name = _tmp4_;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_.pre_check = ___lambda10__set_properties_tests_pre_check;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_.pre_check_target = self;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_.set_property = ___lambda11__set_properties_tests_set_property;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_.set_property_target = self;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_.post_check = ___lambda12__set_properties_tests_post_check;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_.post_check_target = self;
#line 78 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gender_details = _tmp5_;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp6_ = g_strdup ("is-favourite");
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp7_.prop_name);
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_.prop_name = _tmp6_;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_.pre_check = ___lambda13__set_properties_tests_pre_check;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_.pre_check_target = self;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_.set_property = ___lambda14__set_properties_tests_set_property;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_.set_property_target = self;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_.post_check = ___lambda15__set_properties_tests_post_check;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_.post_check_target = self;
#line 94 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	is_favourite_details = _tmp7_;
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp8_ = g_strdup ("nickname");
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp9_.prop_name);
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp9_.prop_name = _tmp8_;
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp9_.pre_check = ___lambda16__set_properties_tests_pre_check;
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp9_.pre_check_target = self;
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp9_.set_property = ___lambda17__set_properties_tests_set_property;
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp9_.set_property_target = self;
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp9_.post_check = ___lambda18__set_properties_tests_post_check;
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp9_.post_check_target = self;
#line 110 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	nickname_details = _tmp9_;
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp10_ = g_strdup ("notes");
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp11_.prop_name);
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp11_.prop_name = _tmp10_;
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp11_.pre_check = ___lambda19__set_properties_tests_pre_check;
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp11_.pre_check_target = self;
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp11_.set_property = ___lambda20__set_properties_tests_set_property;
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp11_.set_property_target = self;
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp11_.post_check = ___lambda21__set_properties_tests_post_check;
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp11_.post_check_target = self;
#line 126 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	notes_details = _tmp11_;
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp12_ = g_strdup ("phone-numbers");
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp13_.prop_name);
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp13_.prop_name = _tmp12_;
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp13_.pre_check = ___lambda22__set_properties_tests_pre_check;
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp13_.pre_check_target = self;
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp13_.set_property = ___lambda23__set_properties_tests_set_property;
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp13_.set_property_target = self;
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp13_.post_check = ___lambda24__set_properties_tests_post_check;
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp13_.post_check_target = self;
#line 149 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	phone_numbers_details = _tmp13_;
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp14_ = g_strdup ("postal-addresses");
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp15_.prop_name);
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp15_.prop_name = _tmp14_;
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp15_.pre_check = ___lambda25__set_properties_tests_pre_check;
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp15_.pre_check_target = self;
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp15_.set_property = ___lambda26__set_properties_tests_set_property;
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp15_.set_property_target = self;
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp15_.post_check = ___lambda27__set_properties_tests_post_check;
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp15_.post_check_target = self;
#line 202 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	postal_addresses_details = _tmp15_;
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp16_ = g_strdup ("roles");
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp17_.prop_name);
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17_.prop_name = _tmp16_;
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17_.pre_check = ___lambda28__set_properties_tests_pre_check;
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17_.pre_check_target = self;
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17_.set_property = ___lambda29__set_properties_tests_set_property;
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17_.set_property_target = self;
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17_.post_check = ___lambda30__set_properties_tests_post_check;
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17_.post_check_target = self;
#line 237 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	roles_details = _tmp17_;
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp18_ = g_strdup ("structured-name");
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp19_.prop_name);
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp19_.prop_name = _tmp18_;
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp19_.pre_check = ___lambda31__set_properties_tests_pre_check;
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp19_.pre_check_target = self;
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp19_.set_property = ___lambda32__set_properties_tests_set_property;
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp19_.set_property_target = self;
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp19_.post_check = ___lambda33__set_properties_tests_post_check;
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp19_.post_check_target = self;
#line 266 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	structured_name_details = _tmp19_;
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp20_ = g_strdup ("urls");
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp21_.prop_name);
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp21_.prop_name = _tmp20_;
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp21_.pre_check = ___lambda34__set_properties_tests_pre_check;
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp21_.pre_check_target = self;
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp21_.set_property = ___lambda35__set_properties_tests_set_property;
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp21_.set_property_target = self;
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp21_.post_check = ___lambda36__set_properties_tests_post_check;
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp21_.post_check_target = self;
#line 284 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	urls_details = _tmp21_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp22_ = birthday_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp22_, &_tmp23_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp24_ = full_name_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp24_, &_tmp25_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp26_ = gender_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp26_, &_tmp27_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp28_ = is_favourite_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp28_, &_tmp29_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp30_ = nickname_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp30_, &_tmp31_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp32_ = notes_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp32_, &_tmp33_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp34_ = phone_numbers_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp34_, &_tmp35_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp36_ = postal_addresses_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp36_, &_tmp37_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp38_ = roles_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp38_, &_tmp39_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp40_ = structured_name_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp40_, &_tmp41_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp42_ = urls_details;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (&_tmp42_, &_tmp43_);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_ = g_new0 (SetPropertiesTestsTestDetails, 11);
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[0] = _tmp23_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[1] = _tmp25_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[2] = _tmp27_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[3] = _tmp29_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[4] = _tmp31_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[5] = _tmp33_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[6] = _tmp35_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[7] = _tmp37_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[8] = _tmp39_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[9] = _tmp41_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp44_[10] = _tmp43_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	properties = _tmp44_;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	properties_length1 = 11;
#line 339 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_properties_size_ = properties_length1;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp45_ = properties;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp45__length1 = properties_length1;
#line 2132 "set-properties.c"
	{
		SetPropertiesTestsTestDetails* _details_collection = NULL;
		gint _details_collection_length1 = 0;
		gint __details_collection_size_ = 0;
		gint _details_it = 0;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_details_collection = _tmp45_;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_details_collection_length1 = _tmp45__length1;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		for (_details_it = 0; _details_it < _tmp45__length1; _details_it = _details_it + 1) {
#line 2144 "set-properties.c"
			SetPropertiesTestsTestDetails _tmp46_ = {0};
			SetPropertiesTestsTestDetails _details = {0};
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			set_properties_tests_test_details_copy (&_details_collection[_details_it], &_tmp46_);
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_details = _tmp46_;
#line 2151 "set-properties.c"
			{
				Block1Data* _data1_;
				SetPropertiesTestsTestDetails _tmp47_ = {0};
				SetPropertiesTestsTestDetails _tmp48_ = {0};
				SetPropertiesTestsTestDetails _tmp49_ = {0};
				const gchar* _tmp50_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_data1_ = g_slice_new0 (Block1Data);
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_data1_->_ref_count_ = 1;
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_data1_->self = g_object_ref (self);
#line 365 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp47_ = _details;
#line 365 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				set_properties_tests_test_details_copy (&_tmp47_, &_tmp48_);
#line 365 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_data1_->details = _tmp48_;
#line 366 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp49_ = _data1_->details;
#line 366 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_tmp50_ = _tmp49_.prop_name;
#line 366 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				folks_test_case_add_test ((FolksTestCase*) self, _tmp50_, _____lambda37__folks_test_case_test_method, block1_data_ref (_data1_), block1_data_unref);
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				set_properties_tests_test_details_destroy (&_details);
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				block1_data_unref (_data1_);
#line 363 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				_data1_ = NULL;
#line 2182 "set-properties.c"
			}
		}
	}
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	properties = (_vala_SetPropertiesTestsTestDetails_array_free (properties, properties_length1), NULL);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&urls_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&structured_name_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&roles_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&postal_addresses_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&phone_numbers_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&notes_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&nickname_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&is_favourite_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&gender_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&full_name_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (&birthday_details);
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return self;
#line 2212 "set-properties.c"
}


SetPropertiesTests* set_properties_tests_new (void) {
#line 39 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return set_properties_tests_construct (TYPE_SET_PROPERTIES_TESTS);
#line 2219 "set-properties.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return _data2_;
#line 2228 "set-properties.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 2237 "set-properties.c"
		SetPropertiesTests* self;
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		self = _data2_->self;
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_g_main_loop_unref0 (_data2_->main_loop);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_g_object_unref0 (self);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		g_slice_free (Block2Data, _data2_);
#line 2247 "set-properties.c"
	}
}


static GValue* _g_value_dup (GValue* self) {
#line 378 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return g_boxed_copy (G_TYPE_VALUE, self);
#line 2255 "set-properties.c"
}


static void _vala_GValue_free (GValue* self) {
#line 378 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_value_unset (self);
#line 378 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_free (self);
#line 2264 "set-properties.c"
}


static gpointer __g_value_dup0 (gpointer self) {
#line 381 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return self ? _g_value_dup (self) : NULL;
#line 2271 "set-properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 385 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 2278 "set-properties.c"
}


static void __lambda38_ (Block2Data* _data2_, GObject* o, GParamSpec* pspec) {
	SetPropertiesTests* self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	SetPropertiesTestsPostCheck _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	GMainLoop* _tmp3_ = NULL;
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	self = _data2_->self;
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (o != NULL);
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (pspec != NULL);
#line 400 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = o;
#line 400 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 400 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	ind = _tmp1_;
#line 401 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = _data2_->post_check;
#line 401 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2__target = _data2_->post_check_target;
#line 401 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ (ind, _tmp2__target);
#line 402 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = _data2_->main_loop;
#line 402 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_main_loop_quit (_tmp3_);
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (ind);
#line 2314 "set-properties.c"
}


static void ___lambda38__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__lambda38_ (self, _sender, pspec);
#line 2321 "set-properties.c"
}


static void _set_properties_tests_test_set_property (SetPropertiesTests* self, const gchar* prop_name, SetPropertiesTestsPreCheck pre_check, void* pre_check_target, SetPropertiesTestsSetProperty set_property, void* set_property_target, SetPropertiesTestsPostCheck post_check, void* post_check_target) {
	Block2Data* _data2_;
	SetPropertiesTestsPostCheck _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GeeHashMap* c1 = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GValue* v = NULL;
	GValue _tmp2_ = {0};
	GValue _tmp3_ = {0};
	GValue* _tmp4_ = NULL;
	GValue* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	GValue* _tmp7_ = NULL;
	GValue* _tmp8_ = NULL;
	EdsTestBackend* _tmp9_ = NULL;
	GeeHashMap* _tmp10_ = NULL;
	GeeHashMap* _tmp11_ = NULL;
	EdsTestBackend* _tmp12_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp13_ = NULL;
	FolksIndividualAggregator* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar** _tmp16_ = NULL;
	gchar** _tmp17_ = NULL;
	gint _tmp17__length1 = 0;
	FolksIndividual* i = NULL;
	FolksIndividualAggregator* _tmp18_ = NULL;
	FolksIndividual* _tmp19_ = NULL;
	GMainLoop* _tmp20_ = NULL;
	gulong handler = 0UL;
	FolksIndividual* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gulong _tmp24_ = 0UL;
	gulong _tmp25_ = 0UL;
	SetPropertiesTestsPreCheck _tmp26_ = NULL;
	void* _tmp26__target = NULL;
	FolksIndividual* _tmp27_ = NULL;
	GMainLoop* _tmp38_ = NULL;
	FolksIndividual* _tmp39_ = NULL;
	gulong _tmp40_ = 0UL;
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (self != NULL);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_return_if_fail (prop_name != NULL);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_data2_->_ref_count_ = 1;
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_data2_->self = g_object_ref (self);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = post_check;
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0__target = post_check_target;
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_data2_->post_check = _tmp0_;
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_data2_->post_check_target = _tmp0__target;
#line 378 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_VALUE, (GBoxedCopyFunc) _g_value_dup, _vala_GValue_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 378 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	c1 = _tmp1_;
#line 381 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_value_init (&_tmp2_, G_TYPE_STRING);
#line 381 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = _tmp2_;
#line 381 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = __g_value_dup0 (&_tmp3_);
#line 381 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__vala_GValue_free0 (v);
#line 381 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	v = _tmp4_;
#line 381 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	G_IS_VALUE (&_tmp3_) ? (g_value_unset (&_tmp3_), NULL) : NULL;
#line 382 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp5_ = v;
#line 382 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_value_set_string (_tmp5_, "bernie h. innocenti");
#line 383 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp6_ = c1;
#line 383 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp7_ = v;
#line 383 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	v = NULL;
#line 383 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp8_ = _tmp7_;
#line 383 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, "full_name", _tmp8_);
#line 383 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__vala_GValue_free0 (_tmp8_);
#line 385 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp9_ = ((EdsTestTestCase*) self)->eds_backend;
#line 385 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp10_ = c1;
#line 385 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp11_ = _g_object_ref0 (_tmp10_);
#line 385 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	eds_test_backend_add_contact (_tmp9_, _tmp11_);
#line 386 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp12_ = ((EdsTestTestCase*) self)->eds_backend;
#line 386 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	eds_test_backend_commit_contacts_to_addressbook_sync (_tmp12_);
#line 390 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp13_ = folks_individual_aggregator_dup ();
#line 390 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	aggregator = _tmp13_;
#line 391 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp14_ = aggregator;
#line 391 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp15_ = g_strdup ("bernie h. innocenti");
#line 391 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp16_ = g_new0 (gchar*, 1 + 1);
#line 391 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp16_[0] = _tmp15_;
#line 391 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17_ = _tmp16_;
#line 391 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17__length1 = 1;
#line 391 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_test_utils_aggregator_prepare_and_wait_for_individuals_sync_with_timeout (_tmp14_, _tmp17_, 1, 5);
#line 391 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp17_ = (_vala_array_free (_tmp17_, _tmp17__length1, (GDestroyNotify) g_free), NULL);
#line 395 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp18_ = aggregator;
#line 395 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp19_ = folks_test_utils_get_individual_by_name (_tmp18_, "bernie h. innocenti");
#line 395 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	i = _tmp19_;
#line 397 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp20_ = g_main_loop_new (NULL, FALSE);
#line 397 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_data2_->main_loop = _tmp20_;
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp21_ = i;
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp22_ = prop_name;
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp23_ = g_strconcat ("notify::", _tmp22_, NULL);
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp24_ = g_signal_connect_data ((GObject*) _tmp21_, _tmp23_, (GCallback) ___lambda38__g_object_notify, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp25_ = _tmp24_;
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 (_tmp23_);
#line 398 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	handler = _tmp25_;
#line 405 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp26_ = pre_check;
#line 405 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp26__target = pre_check_target;
#line 405 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp27_ = i;
#line 405 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp26_ (_tmp27_, _tmp26__target);
#line 2480 "set-properties.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp28_ = NULL;
		GeeSet* _tmp29_ = NULL;
		GeeSet* _tmp30_ = NULL;
		GeeIterator* _tmp31_ = NULL;
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp28_ = i;
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp29_ = folks_individual_get_personas (_tmp28_);
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp30_ = _tmp29_;
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_tmp31_ = gee_iterable_iterator ((GeeIterable*) _tmp30_);
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_p_it = _tmp31_;
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		while (TRUE) {
#line 2499 "set-properties.c"
			GeeIterator* _tmp32_ = NULL;
			gboolean _tmp33_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp34_ = NULL;
			gpointer _tmp35_ = NULL;
			SetPropertiesTestsSetProperty _tmp36_ = NULL;
			void* _tmp36__target = NULL;
			FolksPersona* _tmp37_ = NULL;
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp32_ = _p_it;
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp33_ = gee_iterator_next (_tmp32_);
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			if (!_tmp33_) {
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
				break;
#line 2516 "set-properties.c"
			}
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp34_ = _p_it;
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp35_ = gee_iterator_get (_tmp34_);
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			p = (FolksPersona*) _tmp35_;
#line 408 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp36_ = set_property;
#line 408 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp36__target = set_property_target;
#line 408 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp37_ = p;
#line 408 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_tmp36_ (_tmp37_, _tmp36__target);
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
			_g_object_unref0 (p);
#line 2534 "set-properties.c"
		}
#line 407 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
		_g_object_unref0 (_p_it);
#line 2538 "set-properties.c"
	}
#line 410 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp38_ = _data2_->main_loop;
#line 410 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_test_utils_loop_run_with_timeout (_tmp38_, 5);
#line 412 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp39_ = i;
#line 412 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp40_ = handler;
#line 412 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_signal_handler_disconnect ((GObject*) _tmp39_, _tmp40_);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (i);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (aggregator);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	__vala_GValue_free0 (v);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (c1);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	block2_data_unref (_data2_);
#line 374 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_data2_ = NULL;
#line 2562 "set-properties.c"
}


static void set_properties_tests_test_details_copy (const SetPropertiesTestsTestDetails* self, SetPropertiesTestsTestDetails* dest) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	SetPropertiesTestsPreCheck _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	SetPropertiesTestsSetProperty _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	SetPropertiesTestsPostCheck _tmp4_ = NULL;
	void* _tmp4__target = NULL;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = (*self).prop_name;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 ((*dest).prop_name);
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	(*dest).prop_name = _tmp1_;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2_ = (*self).pre_check;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp2__target = (*self).pre_check_target;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	(*dest).pre_check = _tmp2_;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	(*dest).pre_check_target = _tmp2__target;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3_ = (*self).set_property;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp3__target = (*self).set_property_target;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	(*dest).set_property = _tmp3_;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	(*dest).set_property_target = _tmp3__target;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4_ = (*self).post_check;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp4__target = (*self).post_check_target;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	(*dest).post_check = _tmp4_;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	(*dest).post_check_target = _tmp4__target;
#line 2607 "set-properties.c"
}


static void set_properties_tests_test_details_destroy (SetPropertiesTestsTestDetails* self) {
#line 33 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_free0 ((*self).prop_name);
#line 2614 "set-properties.c"
}


static SetPropertiesTestsTestDetails* set_properties_tests_test_details_dup (const SetPropertiesTestsTestDetails* self) {
	SetPropertiesTestsTestDetails* dup;
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	dup = g_new0 (SetPropertiesTestsTestDetails, 1);
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_copy (self, dup);
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return dup;
#line 2626 "set-properties.c"
}


static void set_properties_tests_test_details_free (SetPropertiesTestsTestDetails* self) {
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_test_details_destroy (self);
#line 31 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_free (self);
#line 2635 "set-properties.c"
}


static GType set_properties_tests_test_details_get_type (void) {
	static volatile gsize set_properties_tests_test_details_type_id__volatile = 0;
	if (g_once_init_enter (&set_properties_tests_test_details_type_id__volatile)) {
		GType set_properties_tests_test_details_type_id;
		set_properties_tests_test_details_type_id = g_boxed_type_register_static ("SetPropertiesTestsTestDetails", (GBoxedCopyFunc) set_properties_tests_test_details_dup, (GBoxedFreeFunc) set_properties_tests_test_details_free);
		g_once_init_leave (&set_properties_tests_test_details_type_id__volatile, set_properties_tests_test_details_type_id);
	}
	return set_properties_tests_test_details_type_id__volatile;
}


static void set_properties_tests_class_init (SetPropertiesTestsClass * klass) {
#line 26 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	set_properties_tests_parent_class = g_type_class_peek_parent (klass);
#line 2653 "set-properties.c"
}


static void set_properties_tests_instance_init (SetPropertiesTests * self) {
}


GType set_properties_tests_get_type (void) {
	static volatile gsize set_properties_tests_type_id__volatile = 0;
	if (g_once_init_enter (&set_properties_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetPropertiesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_properties_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetPropertiesTests), 0, (GInstanceInitFunc) set_properties_tests_instance_init, NULL };
		GType set_properties_tests_type_id;
		set_properties_tests_type_id = g_type_register_static (EDS_TEST_TYPE_TEST_CASE, "SetPropertiesTests", &g_define_type_info, 0);
		g_once_init_leave (&set_properties_tests_type_id__volatile, set_properties_tests_type_id);
	}
	return set_properties_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	SetPropertiesTests* tests = NULL;
	SetPropertiesTests* _tmp0_ = NULL;
#line 418 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_test_init (&args_length1, &args, NULL);
#line 420 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_tmp0_ = set_properties_tests_new ();
#line 420 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	tests = _tmp0_;
#line 421 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 422 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	g_test_run ();
#line 423 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 425 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	result = 0;
#line 425 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	_g_object_unref0 (tests);
#line 425 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return result;
#line 2695 "set-properties.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 416 "/opt/gnome3/source/folks/tests/eds/set-properties.vala"
	return _vala_main (argv, argc);
#line 2705 "set-properties.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



